screenshotControllers property
This list will get initialize when passed to TakeScreenShot widget.
Implementation
List<ScreenShotController>? screenshotControllers;
This list will get initialize when passed to TakeScreenShot widget.
List<ScreenShotController>? screenshotControllers;